Signal functions
----------------

The functions in this section describe non-sinusoidal waveforms, which are
often used in signal processing and electronics.

Square wave signal
..................

.. autofunction:: mpmath.squarew


Triangle wave signal
....................

.. autofunction:: mpmath.trianglew


Sawtooth wave signal
....................

.. autofunction:: mpmath.sawtoothw


Unit triangle signal
....................

.. autofunction:: mpmath.unit_triangle


Sigmoid wave signal
.....................

.. autofunction:: mpmath.sigmoid
